@@ -15,5 +15,5 @@ class WebDebugger(WebPdb):
         pytest --pdbcls=ocp_utilities.debugger:WebDebugger --pdb
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(host="0.0.0.0", port=int(os.environ.get("PYTHON_REMOTE_DEBUG_PORT", 1212)))
